
var currentMapLoad;

/**
 * create the map
 *
 * @param Object properties : map properties
 * @param Integer gmapsIndex : index in the map list
 */
function createMap(properties, gmapsIndex)
{
  var map = new google.maps.Map($("#"+properties.id).get(0),
    {
      backgroundColor:'#ffffff',
      mapTypeId: properties.mapType,
      zoom: properties.zoomLevel,
      center: gmaps.bounds.getCenter(),
      navigationControl: (properties.navigationControl==-1)?false:true,
      scrollwheel: (properties.navigationControl==-1)?false:true,
      scaleControl: (properties.scaleControl=='n')?false:true,
      mapTypeControl:(properties.mapTypeControl==-1)?false:true,
      mapTypeControlOptions:
        {
          style:properties.mapTypeControl
        },
      markerTitle:'',
    }
  );

  if(properties.kmlFileUrl!='')
  {
    kmlFile = new google.maps.KmlLayer(properties.kmlFileUrl,
      {
        preserveViewport:true
      }
    );
  }
  else
  {
    kmlFile=null;
  }

  map.kmlFile=kmlFile;
  map.markers=new Array();
  map.gmapsIndex=gmapsIndex;
  properties.gMap=map;
  properties.viewportInitialized=false;
}

/**
 * load markers from the server
 *
 * @param Map map : the map
 */
function loadMarkers(map)
{
  datas={
    requestId:gmaps.requestId,
    bounds:{
        north:map.getBounds().getNorthEast().lat(),
        east:map.getBounds().getNorthEast().lng(),
        south:map.getBounds().getSouthWest().lat(),
        west:map.getBounds().getSouthWest().lng()
      },
    width:$(map.getDiv()).width(),
    height:$(map.getDiv()).height(),
    distanceTreshold:20
  }

  currentMapLoad=map;

  $('#gmapsLoading').css('display', 'inline-block');
  $('#gmapsNbPhotos').html('');
  $('#iDialogGMapWaiting').css(
    {
      width:$('#iGMapsIcon').width()+'px',
      height:$('#iGMapsIcon').height()+'px',
      top:$('#iGMapsIcon').position().top+'px',
      left:$('#iGMapsIcon').position().left+'px',
      display:'block'
    }
  );

  $.ajax(
    {
      type: "POST",
      url: "plugins/GMaps/gmaps_ajax.php",
      async: true,
      data: { ajaxfct:"public.maps.getMarkers", datas:datas },
      success:
        function(msg)
        {
          tmp=$.parseJSON(msg);
          tmp.markers.sort(compareMarkers);
          applyMarkers(currentMapLoad, tmp.markers);
          $('#gmapsLoading').css('display', 'none');
          $('#gmapsNbPhotos').html('['+tmp.datas.nbPhotos+']');
          $('#iDialogGMapWaiting').css('display', 'none');
        }
    }
  );
}

/**
 * apply markers to map
 *
 * @param Map map : the google map object
 * @param Array markers : array of markers properties
 *                        each marker is an object with properties :
 *                          latitude, longitude, nbImages
 */
function applyMarkers(map, markers)
{
  if(currentMapLoad==null) return(false);

  /*
   * deleting markers from the map only if they are not in the new list
   */
  if(map.markers.length>0)
  {
    var i=0;
    while(i<map.markers.length)
    {
      newListIndex=markerInList(map.markers[i].uniqueId, markers);
      if(newListIndex==-1)
      {
        map.markers[i].marker.setMap(null);
        map.markers.splice(i, 1);
      }
      else
      {
        markers.splice(newListIndex,1);
        i++;
      }
    }
  }

  /*
   * add new markers on the map
   */
  for(var i=0;i<markers.length;i++)
  {
    var marker = new google.maps.Marker(
      {
        position:new google.maps.LatLng(markers[i].lat, markers[i].lng),
        map: currentMapLoad,
        title:markers[i].nbImgTxt
      }
    );

    marker.info=markers[i];
    marker.info.displayed=0;

    map.markers.push(
      {
        marker:marker,
        uniqueId:markers[i].uniqueId
      }
    );

    google.maps.event.addListener(
      marker,
      'click',
      function ()
      {
        displayWindowInfo(this);
      }
    );
  }
  currentMapLoad=null;
}

function compareMarkers(m1,m2)
{
  if(m1.uniqueId<m2.uniqueId)
  {
    return(-1);
  }
  else if(m1.uniqueId<m2.uniqueId)
  {
    return(1);
  }
  return(0);
}

function markerInList(uniqueId, markerList)
{
  for(var i=0;i<markerList.length;i++)
  {
    if(markerList[i].uniqueId==uniqueId) return(i)
  }
  return(-1);
}

/**
 * display the infowindow
 *
 * @param Marker marker : the marker
 */
function displayWindowInfo(marker)
{
  gmaps.currentInfo=marker.info;
  gmaps.infoWindow.close();
  gmaps.infoWindow.setContent($('#iGMapsInfoWindowContent').clone().each(renameId).get(0));
  gmaps.infoWindow.open(marker.map, marker);
  displayPictureInfo(gmaps.currentInfo.displayed);
}
function renameId(i, e)
{
  if(e.id!='') e.id='c'+e.id;
  $(e).children().each(renameId);
}


/**
 *
 */
function displayPictureInfo(index)
{
  gmaps.currentInfo.displayed=index;
  if(gmaps.currentInfo.imgName[index]=='')
  {
    $('#ciGMIWC_title').html('&nbsp;');
  }
  else
  {
    $('#ciGMIWC_title').html(gmaps.currentInfo.imgName[index]);
  }
  $('#ciGMIWC_img').attr('src', './galleries/'+gmaps.currentInfo.imgTn[index]);

  $('#ciGMIWC_img').unbind();
  if(gmaps.currentInfo.imgCatsUrl[index].length==1)
  {
    $('#ciGMIWC_img').bind('click',
      function ()
      {
        window.location=gmaps.currentInfo.imgCatsUrl[gmaps.currentInfo.displayed][0];
      }
    );
  }
  else
  {
    $('#ciGMIWC_showcatList').html('');
    for(var i=0;i<gmaps.currentInfo.imgCatsUrl[index].length;i++)
    {
      $('#ciGMIWC_showcatList')
        .append('<li><a href="'+gmaps.currentInfo.imgCatsUrl[index][i]+'">'+gmaps.currentInfo.imgCatsNames[index][i]+'</a></li>');
    }
    $('#ciGMIWC_img, #ciGMIWC_showcat')
      .bind('mouseenter', function () { $('#ciGMIWC_showcat').css('display', 'block'); } )
      .bind('mouseleave', function () { $('#ciGMIWC_showcat').css('display', 'none'); } );
  }

  if(gmaps.currentInfo.nbImages>1)
  {
    $('#ciGMIWC_picnum').html((index+1)+'/'+gmaps.currentInfo.nbImgTxt);
    $('#ciWALeft, #ciWARight').css('display', 'inline-block');
  }
  else
  {
    $('#ciGMIWC_picnum').html(gmaps.currentInfo.nbImgTxt);
    $('#ciWALeft, #ciWARight').css('display', 'none');
  }
}

/**
 *
 */
function displayPicturePrev()
{
  gmaps.currentInfo.displayed--;
  if(gmaps.currentInfo.displayed<0) gmaps.currentInfo.displayed=gmaps.currentInfo.nbImages-1;
  displayPictureInfo(gmaps.currentInfo.displayed);
}

/**
 *
 */
function displayPictureNext()
{
  gmaps.currentInfo.displayed++;
  if(gmaps.currentInfo.displayed>=gmaps.currentInfo.nbImages) gmaps.currentInfo.displayed=0;
  displayPictureInfo(gmaps.currentInfo.displayed);
}


$(window).load(function ()
  {
    // all maps have the same intials bounds
    gmaps.currentInfo=null;

    gmaps.bounds = new google.maps.LatLngBounds(
      new google.maps.LatLng(gmaps.bounds.south, gmaps.bounds.west),
      new google.maps.LatLng(gmaps.bounds.north, gmaps.bounds.east)
    );

    gmaps.infoWindow = new google.maps.InfoWindow();
    google.maps.event.addListener(
     gmaps.infoWindow,
     'closeclick',
     function () {
       $('body').append($('#iGMapsInfoWindowContent'));
       gmaps.infoWindow.setContent('');
       $('#ciGMIWC_img').unbind();
     }
    );


    for(var i=0;i<gmaps.maps.length;i++)
    {
      // prepare google map maps
      createMap(gmaps.maps[i], i);

      // if size map depends from windows size, apply new dimensions to map
      if(gmaps.maps[i].sizeMode=='A')
      {
        $('#'+gmaps.maps[i].id).css(
          {
            width: ($(window).width()*0.8)+'px',
            height:($(window).height()*0.8)+'px'
          }
        );
      }

      // initialize dialog box for maps
      $('#'+gmaps.maps[i].id+'Content').dialog(
        {
          autoOpen:false,
          width:'auto',
          height:'auto',
          modal: true,
          closeText:'X',
          dialogClass: 'gmapsPopup',
          title: gmaps.maps[i].title,
          open: function ()
            {
              gmaps.currentMapLoadIndex=$(this).data('index');

              /*
               * initialize map on the server side (call the 'public.maps.init'
               * function
               */
              $.ajax(
                {
                  type: "POST",
                  url: "plugins/GMaps/gmaps_ajax.php",
                  async: true,
                  data: { ajaxfct:"public.maps.init", category:gmaps.categoryId },
                  success:
                    function(msg)
                    {
                      gmaps.requestId=msg;

                      if(gmaps.maps[gmaps.currentMapLoadIndex].viewportInitialized==false)
                      {
                        /*
                         * if the container is not visible when map are built, they are
                         * not initialized correctly
                         *
                         * when dialog is opened for the first time, proceed to map
                         * finalization :
                         *  - resize
                         *  - center the map
                         *  - add handlers on events 'dragend' and 'zoom_change'
                         *    allowing to reload markers according to the new viewport
                         */
                        google.maps.event.trigger(gmaps.maps[gmaps.currentMapLoadIndex].gMap, 'resize');


                        if(gmaps.maps[gmaps.currentMapLoadIndex].fitToBounds)
                        {
                          gmaps.maps[gmaps.currentMapLoadIndex].gMap.fitBounds(gmaps.bounds);
                        }
                        else
                        {
                          gmaps.maps[gmaps.currentMapLoadIndex].gMap.setCenter(gmaps.bounds.getCenter());
                        }

                        // reduce copyright size... ^_^
                        $('#'+gmaps.maps[gmaps.currentMapLoadIndex].id+' span, #'+gmaps.maps[gmaps.currentMapLoadIndex].id+' a').css('font-size', '55.0%');

                        if(gmaps.maps[gmaps.currentMapLoadIndex].gMap.kmlFile!=null)
                          gmaps.maps[gmaps.currentMapLoadIndex].gMap.kmlFile.setMap(gmaps.maps[gmaps.currentMapLoadIndex].gMap);

                        google.maps.event.addListener(
                          gmaps.maps[gmaps.currentMapLoadIndex].gMap,
                          'dragend',
                          function()
                          {
                            loadMarkers(this);
                            $('#gmapsBoundMap').css('display', 'inline');
                            $('#gmapsBoundKml').css('display', 'inline');
                          }
                        );

                        google.maps.event.addListener(
                          gmaps.maps[gmaps.currentMapLoadIndex].gMap,
                          'zoom_changed',
                          function()
                          {
                            loadMarkers(this);
                            gmaps.infoWindow.close();
                            $('#gmapsBoundMap').css('display', 'inline');
                            $('#gmapsBoundKml').css('display', 'inline');
                          }
                        );

                        // loads the markers
                        loadMarkers(gmaps.maps[gmaps.currentMapLoadIndex].gMap);
                        gmaps.maps[gmaps.currentMapLoadIndex].viewportInitialized=true;
                      }

                    }
                }
              );
            }
        }
      ).data('index', i);

      $('div.gmapsPopup div.ui-dialog-titlebar')
      .append('<a href="" id="gmapsBoundMap" style="display:none;" onclick="gmaps.maps[gmaps.currentMapLoadIndex].gMap.fitBounds(gmaps.bounds); $(this).css(\'display\', \'none\').blur(); return(false);">'+
              '<span>&there4;</span></a>');
      $('#gmapsBoundMap').attr('title', gmaps.lang.boundmap);

      if(gmaps.maps[i].gMap.kmlFile!=null)
      {
        $('div.gmapsPopup div.ui-dialog-titlebar')
          .append('<a href="" id="gmapsBoundKml" onclick="gmaps.maps[gmaps.currentMapLoadIndex].gMap.fitBounds(gmaps.maps[gmaps.currentMapLoadIndex].gMap.kmlFile.getDefaultViewport()); $(this).css(\'display\', \'none\').blur(); return(false);">'+
                  '<span>&sim;</span></a>');
        $('#gmapsBoundKml').attr('title', gmaps.lang.boundkml);
      }

      $('div.gmapsPopup div.ui-dialog-titlebar')
      .append('<span id="gmapsLoading" style="display:none;"><img src="./plugins/GrumPluginClasses/icons/processing.gif"><span>'+gmaps.lang.loading+'</span></span>');

      $('#ui-dialog-title-iGMapsIconContent')
      .append('<span id="gmapsNbPhotos"></span>');


    }

  }
);


